StackBox

Struct StackBox 

pub struct StackBox<T, Ctnr>
where T: ?Sized,
{ /* private fields */ }

Implementations

Source

impl<T, Ctnr> StackBox<T, Ctnr>
where Ctnr: StackBoxContainer,

pub fn new(value: T) -> Self

Statically check if value could be put into this box. If checking is failed then trigger error at compile time.

Examples found in repository?
examples/cells.rs (line 8)
7fn main() {
8    let cb = CellBox::new(RefCell::new(10u32)); // internal mutability
9    let r1 = cb.borrow();
10    let r2 = cb.borrow();
11    drop((r1, r2));
12    *cb.borrow_mut() = 99;
13}
More examples
Hide additional examples
examples/basic.rs (line 8)
7fn main() {
8    let u16_box = U32Box::new(16u16); // ok
9    let u32_box = U32Box::new([32u32; 3]); // ok
10
11    // U32Box::new(0u64); // panic at compile time
12    // U32Box::new([0u32; 4]); // panic at compile time
13
14    assert!(U32Box::new_dynamic(0u64).is_err()); // align too large
15    assert!(U32Box::new_dynamic([0u32; 4]).is_err()); // size too large
16
17    let arr: [U32Box<dyn Debug>; 2] = [coerce!(u16_box), coerce!(u32_box)];
18
19    for x in arr {
20        dbg!(&*x);
21    }
22}
pub fn new_dynamic(value: T) -> Result<Self, (T, Error)>

Same to Self::new but does check at runtime and returns a Result

Examples found in repository?
examples/basic.rs (line 14)
7fn main() {
8    let u16_box = U32Box::new(16u16); // ok
9    let u32_box = U32Box::new([32u32; 3]); // ok
10
11    // U32Box::new(0u64); // panic at compile time
12    // U32Box::new([0u32; 4]); // panic at compile time
13
14    assert!(U32Box::new_dynamic(0u64).is_err()); // align too large
15    assert!(U32Box::new_dynamic([0u32; 4]).is_err()); // size too large
16
17    let arr: [U32Box<dyn Debug>; 2] = [coerce!(u16_box), coerce!(u32_box)];
18
19    for x in arr {
20        dbg!(&*x);
21    }
22}
pub fn coerce_unsized<U, F>(this: Self, check_fn: F) -> StackBox<U, Ctnr>
where U: ?Sized, F: Fn(&mut UnsizeChecker<U, T>) -> &mut UnsizeChecker<U, U>,

Source

impl<T, Ctnr> StackBox<T, Ctnr>
where T: ?Sized,

pub fn as_ptr(this: &Self) -> *mut T